import * as tailwindcss_types_config from 'tailwindcss/types/config';
import typography from '@tailwindcss/typography';

declare const customCSS: {
    ".av-text-input-wrapper label[aria-hidden=\"true\"],\n\t\t.av-text-area-wrapper label[aria-hidden=\"true\"]": {
        transform: string;
        transformOrigin: string;
        transition: string;
    };
    '.av-text-input:focus + label[aria-hidden="true"],\n\t.av-text-input:not(:placeholder-shown) + label[aria-hidden="true"],\n\t.av-text-area:focus + label[aria-hidden="true"],\n\t.av-text-area:not(:placeholder-shown) + label[aria-hidden="true"]': {
        transform: string;
    };
    ".av-text-input-helper-text,\n\t.av-text-area-helper-text": {
        transform: string;
        transformOrigin: string;
    };
    ".av-text-input__control--right,\n\t.av-text-area__control--right": {
        right: string;
    };
    "@keyframes blink": {
        "50%": {
            fill: string;
        };
    };
    ".av-spinner__dot": {
        animation: string;
    };
    ".av-spinner__dot:nth-child(2)": {
        animationDelay: string;
    };
    ".av-spinner__dot:nth-child(3)": {
        animationDelay: string;
    };
};

declare const twPlugin: {
    content: string[];
    safelist: string[];
    plugins: (typeof typography | {
        handler: tailwindcss_types_config.PluginCreator;
        config?: Partial<tailwindcss_types_config.Config> | undefined;
    })[];
    merge: (config: any) => any;
};

declare const tokens: {
    colors: {
        /**
         * Action tokens.
         */
        "action-dark": "#0f172a";
        "action-dark-hover": "#334155";
        "action-dark-active": "#475569";
        "action-light": "#64748b";
        "action-light-hover": "#475569";
        "action-light-active": "#334155";
        /**
         * Surface tokens.
         */
        "surface-dark": "#0f172a";
        "surface-medium": "#64748b";
        "surface-light": "#cbd5e1";
        "surface-lighter": "#e2e8f0";
        "surface-accent": string;
        /**
         * Typography tokens.
         */
        "copy-dark": "#0f172a";
        "copy-dark-hover": "#0f172a";
        "copy-dark-active": "#0f172a";
        "copy-medium": "#94a3b8";
        "copy-medium-hover": "#94a3b8";
        "copy-medium-active": "#94a3b8";
        "copy-light": "#e2e8f0";
        "copy-light-hover": "#e2e8f0";
        "copy-light-active": "#94a3b8";
        "copy-lighter": string;
        "copy-lighter-hover": string;
        "copy-lighter-active": string;
        "copy-error-dark": string;
        "copy-error-light": string;
        /**
         * Border tokens.
         */
        "border-dark": "#0f172a";
        "border-medium": "#94a3b8";
        "border-light": "#cbd5e1";
        "border-white": string;
        "border-error-dark": string;
        "border-error-light": string;
        /**
         * Focus tokens.
         */
        "focus-dark": "#0f172a";
        "focus-light": "#cbd5e1";
        "focus-error-dark": string;
        "focus-error-light": string;
        /**
         * Table tokens
         */
        "table-dark": "#374151";
        "table-dark-odd": "#1f2937";
        "table-dark-even": "#111827";
        "table-light": "#f3f4f6";
        "table-light-odd": "#e5e7eb";
        "table-light-even": "#d1d5db";
    };
};

export { customCSS, tokens, twPlugin };
